import { Base } from "./Base.mjs"
import { Agenda } from "../pieces/Agenda.mjs"
import { getKey } from "../../account.mjs"
import { ButtonAndTextLink } from "../pieces/ButtonAndTextLink.mjs"
import {
    getLatestProtocolMetadata,
    getProtocolEditLink,
} from "../../gitlab.mjs"

const items = {
    all: null,
    message: "Wird geladen...",
    async fetch() {
        try {
            this.all = await m.request({
                method: "GET",
                url: "/api/v0/agendas/-/items",
                headers: getKey()
                    ? {
                          Authorization: `Bearer ${getKey().secret}`,
                      }
                    : {},
            })
        } catch (e) {
            if (e.code === 401) {
                this.message =
                    "Melde dich an Portal an, um die Tagesordnung anzuzeigen."
            } else {
                this.message = "Die Tagesordnung konnte nicht geladen werden."
            }
        }
    },
}

const latestProtocol = {
    meta: null,
    async fetch() {
        this.meta = await getLatestProtocolMetadata()
        m.redraw()
    },
}

export const Fachschaftssitzung = {
    oncreate() {
        document.title = "Fachschaftssitzung · FS Coli Portal"
    },
    async oninit() {
        items.fetch()
        latestProtocol.fetch()
    },
    view() {
        return m(Base, [
            m(Agenda, {
                items: items.all?.map(item => item.name),
                message: items.message,
            }),
            m("section", [
                m(
                    "p",
                    m(ButtonAndTextLink, {
                        href:
                            latestProtocol.meta?.editLink ||
                            getProtocolEditLink(
                                new Date().toISOString().split("T")[0],
                            ),
                        icon: "fa-solid fa-file-pen",
                        name: latestProtocol.meta
                            ? "Aktuelles Protokoll bearbeiten"
                            : "Heutiges Protokoll bearbeiten",
                    }),
                ),
                latestProtocol.meta &&
                    m(
                        "p",
                        m(ButtonAndTextLink, {
                            href: latestProtocol.meta?.downloadLink,
                            icon: "fa-regular fa-file-pdf",
                            name: "Protokoll als PDF herunterladen",
                        }),
                    ),
                latestProtocol.meta?.containsResolution &&
                    m(
                        "p",
                        m(ButtonAndTextLink, {
                            href: latestProtocol.meta?.resolutionDownloadLink,
                            icon: "fa-solid fa-gavel",
                            name: "Beschlüsse als PDF herunterladen",
                        }),
                    ),
                !latestProtocol.meta &&
                    m(
                        "p",
                        m(ButtonAndTextLink, {
                            href: "https://gitlab.cl.uni-heidelberg.de/fachschaft/protokolle",
                            icon: "fa-brands fa-gitlab",
                            name: "Bei GitLab anmelden, um Protokolle herunterzuladen",
                            onclick: () => {
                                setTimeout(() => {
                                    document.addEventListener(
                                        "visibilitychange",
                                        () => {
                                            if (!document.hidden) {
                                                location.reload()
                                            }
                                        },
                                    )
                                }, 1000)
                            },
                        }),
                    ),
            ]),
        ])
    },
}
