import { Service } from "../../model/Service.mjs"
import { ServiceLink } from "../pieces/ServiceLink.mjs"
import { Base } from "./Base.mjs"

const germanDateFormatter = new Intl.DateTimeFormat("de-DE", {
    month: "2-digit",
    day: "2-digit",
    year: "numeric",
})

function getMensaLink() {
    const dayToShow = new Date()
    if (dayToShow.getHours() >= 15) {
        // If it is 15:00 or later, show tomorrow's menu
        dayToShow.setDate(dayToShow.getDate() + 1)
    }

    return `https://www.stw.uni-heidelberg.de/external-tools/speiseplan/speiseplan.php?lang=de&mode=Mensa+Im+Neuenheimer+Feld+304&date=${germanDateFormatter.format(dayToShow)}`
}

export const UniServices = {
    oncreate() {
        document.title = "Uni-Dienste · FS Coli Portal"
    },
    view() {
        return m(
            Base,
            m("article.services", [
                m(
                    ServiceLink,
                    new Service(
                        "CL-Mail",
                        "https://mail.cl.uni-heidelberg.de/",
                        "fa-solid fa-at",
                        "CL-Account",
                    ),
                ),
                m(
                    ServiceLink,
                    new Service(
                        "Moodle",
                        "https://moodle.uni-heidelberg.de/",
                        "fa-solid fa-school-flag",
                        "Uni-ID",
                    ),
                ),
                m(
                    ServiceLink,
                    new Service(
                        "Uni-Mail",
                        "https://sogo.uni-heidelberg.de/",
                        "fa-solid fa-inbox",
                        "Uni-ID",
                    ),
                ),
                m(
                    ServiceLink,
                    new Service(
                        "HeiCo",
                        "https://heico.uni-heidelberg.de/",
                        "fa-solid fa-graduation-cap",
                        "Uni-ID",
                    ),
                ),
                m(
                    ServiceLink,
                    new Service(
                        "Mensa INF",
                        getMensaLink(),
                        "fa-solid fa-utensils",
                    ),
                ),
            ]),
        )
    },
}
